@@ -14,8 +14,18 @@ Including another URLconf
     2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
 """
 from django.contrib import admin
-from django.urls import path
+from django.urls import path, re_path, include
+from django.contrib.flatpages.sitemaps import FlatPageSitemap
+from django.contrib.sitemaps.views import sitemap
+
 
 urlpatterns = [
     path('admin/', admin.site.urls),
+
+    # the sitemap
+    path('sitemap.xml', sitemap,
+         {'sitemaps': {'flatpages': FlatPageSitemap}},
+         name='django.contrib.sitemaps.views.sitemap'),
+
+    re_path(r'^$', include('django.contrib.flatpages.urls')),
 ]
