@@ -1,3 +1,5 @@
+import sys
+
 from django.apps import AppConfig
 
 
@@ -9,8 +11,9 @@ class DjangoProjectBackupConfig(AppConfig):
         from .settings import DJANGO_PROJECT_BACKUP_SHAPE
 
         if DJANGO_PROJECT_BACKUP_SHAPE == 'realtime':
-            try:
-                from . import signals  # noqa F401
+            if "migrate" not in sys.argv:  # disable for django "migrate" command
+                try:
+                    from . import signals  # noqa F401
 
-            except ImportError:
-                pass
+                except ImportError:
+                    pass
