@@ -8,10 +8,13 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         try:
-           loaddata()
+            loaded_ids = loaddata()
+
+            self.stdout.write(self.style.SUCCESS('Loaded: {}'.format(loaded_ids)))
 
         except Exception as e:
             self.stdout.write(self.style.ERROR('Error "{}"'.format(e)))
+            raise
 
         else:
             self.stdout.write(self.style.SUCCESS('Done'))
