@@ -1,10 +1,13 @@
 import json
+import datetime
+
+from django.utils import timezone
 
 from cloudant import CouchDB
 from cloudant.error import CloudantDatabaseException
 
-from ...settings import COUCHDB_DATASTORE_USER, COUCHDB_DATASTORE_PASSWORD, COUCHDB_DATASTORE_HOST, \
-                        COUCHDB_DATASTORE_DATABASE_NAME
+from ...settings import COUCHDB_DATASTORE_USER, COUCHDB_DATASTORE_PASSWORD, COUCHDB_DATASTORE_URL, \
+                        COUCHDB_DATASTORE_DATABASE_NAME, DJANGO_PROJECT_BACKUP_MODE
 
 
 def response_to_json_dict(response, **kwargs):
@@ -25,23 +28,35 @@ class DBAdapter:
     """
     CouchDB DBAdapter
     """
+
+    def get_database_name(self):
+        if DJANGO_PROJECT_BACKUP_MODE == 'full':
+            now = timezone.now()
+            return '{}__{}'.format(COUCHDB_DATASTORE_DATABASE_NAME,
+                                   now.strftime("%Y_%m_%d"))
+        else:
+            return COUCHDB_DATASTORE_DATABASE_NAME
+
     def __init__(self):
         self.client = CouchDB(COUCHDB_DATASTORE_USER, COUCHDB_DATASTORE_PASSWORD,
-                              url=COUCHDB_DATASTORE_HOST,
+                              url=COUCHDB_DATASTORE_URL,
                               connect=True,
                               auto_renew=True,
                               use_basic_auth=True)
 
+        database_name = self.get_database_name()
+
         try:
-            self.database = self.client[COUCHDB_DATASTORE_DATABASE_NAME]
+            self.database = self.client[database_name]
         except KeyError:
-            self.database = self.client.create_database(COUCHDB_DATASTORE_DATABASE_NAME)
+            self.database = self.client.create_database(database_name)
 
     def __del__(self):
         self.client.disconnect()
 
     def get_documents_ids(self):
-        url = '/'.join((self.client.server_url, COUCHDB_DATASTORE_DATABASE_NAME, '_all_docs'))
+        database_name = self.get_database_name()
+        url = '/'.join((self.client.server_url, database_name, '_all_docs'))
 
         resp = self.client.r_session.get(url)
         resp.raise_for_status()
