@@ -37,9 +37,13 @@ class CouchdbStream:
     def get_output_name(self):
         return self.output.name
 
-    def send(self):
-        for obj in self.read():
-            # send to couchdb
+    def send(self, obj=None):
+        if obj is None:
+            for obj in self.read():
+                # send to couchdb
+                self.db.put_document(obj)
+                self.sent_ids.append(obj['_id'])
+        else:
             self.db.put_document(obj)
             self.sent_ids.append(obj['_id'])
 
